==> seedsui-react-5.8.64.tgz: package/lib/Skeleton/components/Paragraph.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
var _excluded = ["length", "animated", "avatarProps", "titleProps", "itemProps", "oddProps", "evenProps"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React from 'react';
import Block from "./Block";
var Paragraph = function Paragraph(_ref) {
  var length = _ref.length,
    _ref$animated = _ref.animated,
    animated = _ref$animated === void 0 ? true : _ref$animated,
    avatarProps = _ref.avatarProps,
    _ref$titleProps = _ref.titleProps,
    titleProps = _ref$titleProps === void 0 ? {} : _ref$titleProps,
    _ref$itemProps = _ref.itemProps,
    itemProps = _ref$itemProps === void 0 ? {} : _ref$itemProps,
    _ref$oddProps = _ref.oddProps,
    oddProps = _ref$oddProps === void 0 ? {} : _ref$oddProps,
    _ref$evenProps = _ref.evenProps,
    evenProps = _ref$evenProps === void 0 ? {} : _ref$evenProps,
    props = _objectWithoutProperties(_ref, _excluded);
  return /*#__PURE__*/React.createElement("div", _extends({
    className: "skeleton-card"
  }, props), avatarProps && /*#__PURE__*/React.createElement(Block, _extends({}, avatarProps, {
    className: "skeleton-avatar".concat(avatarProps.className ? ' ' + avatarProps.className : '')
  })), /*#__PURE__*/React.createElement("div", {
    className: "skeleton-card-content"
  }, titleProps && /*#__PURE__*/React.createElement(Block, _extends({}, titleProps, {
    className: "skeleton-title".concat(titleProps.className ? ' ' + titleProps.className : '')
  })), Array.from({
    length: length !== null && length !== void 0 ? length : 2
  }).map(function (_, index) {
    var currentItemProps = _objectSpread(_objectSpread({}, itemProps), (index + 1) % 2 === 0 ? evenProps : oddProps);
    return /*#__PURE__*/React.createElement(Block, _extends({
      key: index
    }, currentItemProps, {
      className: "skeleton-item".concat(props.className ? ' ' + props.className : '')
    }));
  })));
};
export default Paragraph;

==> seedsui-react-5.8.79.tgz: package/lib/Skeleton/components/Paragraph.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
var _excluded = ["length", "animated", "avatarProps", "titleProps", "itemProps", "oddProps", "evenProps"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React from 'react';
import Block from "./Block";
var Paragraph = function Paragraph(_ref) {
  var length = _ref.length,
    _ref$animated = _ref.animated,
    animated = _ref$animated === void 0 ? true : _ref$animated,
    avatarProps = _ref.avatarProps,
    _ref$titleProps = _ref.titleProps,
    titleProps = _ref$titleProps === void 0 ? {} : _ref$titleProps,
    _ref$itemProps = _ref.itemProps,
    itemProps = _ref$itemProps === void 0 ? {} : _ref$itemProps,
    _ref$oddProps = _ref.oddProps,
    oddProps = _ref$oddProps === void 0 ? {} : _ref$oddProps,
    _ref$evenProps = _ref.evenProps,
    evenProps = _ref$evenProps === void 0 ? {} : _ref$evenProps,
    props = _objectWithoutProperties(_ref, _excluded);
  return /*#__PURE__*/React.createElement("div", _extends({
    className: "skeleton-card"
  }, props), avatarProps && /*#__PURE__*/React.createElement(Block, _extends({
    animated: animated
  }, avatarProps, {
    className: "skeleton-avatar".concat(avatarProps.className ? ' ' + avatarProps.className : '')
  })), /*#__PURE__*/React.createElement("div", {
    className: "skeleton-card-content"
  }, titleProps && /*#__PURE__*/React.createElement(Block, _extends({
    animated: animated
  }, titleProps, {
    className: "skeleton-title".concat(titleProps.className ? ' ' + titleProps.className : '')
  })), Array.from({
    length: length !== null && length !== void 0 ? length : 2
  }).map(function (_, index) {
    var currentItemProps = _objectSpread(_objectSpread({}, itemProps), (index + 1) % 2 === 0 ? evenProps : oddProps);
    return /*#__PURE__*/React.createElement(Block, _extends({
      animated: animated,
      key: index
    }, currentItemProps, {
      className: "skeleton-item".concat(props.className ? ' ' + props.className : '')
    }));
  })));
};
export default Paragraph;
